import React, { useState, useEffect, useRef } from "react";
import { TextInput, Row } from "react-materialize";
import { i18n } from "meteor/universe:i18n";

const WAIT_INTERVAL = 700; //interval research data view
const ENTER_KEY = 13;

const Search = ({
  search: fulltext,
  refSearch=null,
  onSearch: setFulltext,
  label = i18n.__("messages.search") + " ...",
}) => {
  const [temp, setTemp] = useState(fulltext);
  //ref pre timer
  const refTimer = useRef(null);

  useEffect(() => {
    setTemp(fulltext);
    return () => {
      if (refTimer.current) {
        Meteor.clearTimeout(refTimer.current);
      }
    };
  }, [fulltext]);

  const onEnter = () => {
    if (refTimer.current) {
      Meteor.clearTimeout(refTimer.current);
      refTimer.current = null;
    }
    setFulltext(temp);
  };
  const onInputChange = (value) => {
    const _value = value || "";
    setTemp(_value);
    if (refTimer.current) {
      Meteor.clearTimeout(refTimer.current);
      refTimer.current = null;
    }
    refTimer.current = Meteor.setTimeout(() => {
      setFulltext(_value);
    }, WAIT_INTERVAL);
  };

  return (
    <Row>
      <TextInput
        ref={refSearch}
        s={12}
        label={label}
        value={temp || ""}
        onChange={(e) => onInputChange(e.target.value)}
        onKeyDown={(e) => {
          if (e.keyCode === ENTER_KEY) {
            onEnter();
          }
        }}
      />
    </Row>
  );
};

export default Search;
