import React, { useState, useEffect, useRef } from "react";
import _ from "lodash";
//import { TextInput, Row } from "react-materialize";

const TableBody = ({ rows, renderRow, headers, columns }) => {
  renderRowImpl = (row) => {
    if (renderRow) {
      return renderRow(row);
    }
    const cells = headers
      .filter((h) => h.field === "action" || columns[h.field])
      .map((h, index) => {
        if (h.render && h.render instanceof Function) {
          return h.render(row, h);
        }
        let value = _.get(row, h.field);
        if (h.formatter) {
          if (h.type === "array") {
            value =
              value && Array.isArray(value)
                ? value.map((r) => h.formatter(r)).join(", ")
                : "";
          } else {
            value = h.formatter(value);
          }
        } else {
          switch (h.type) {
            case "array":
              value = value && Array.isArray(value) ? value.join(", ") : "";
              break;

            case "date":
              const formatDate = h.format || "DD.MM.YYYY";
              value = moment(value).format(formatDate);
              break;

            case "datetime":
              const formatDateTime = h.format || "DD.MM.YYYY hh:mm";
              value = moment(value).format(formatDateTime);
              break;

            case "boolean":
              value = value ? (
                <i
                  className={"fa fa-check green-text text-darken-3"}
                  aria-hidden={true}
                ></i>
              ) : (
                <i
                  className={"fa fa-times red-text text-darken-2"}
                  aria-hidden={true}
                ></i>
              );
              break;
          }
        }
        value = value || "";
        if (h.onClick) {
          value = (
            <a
              href="#"
              onClick={(event) => {
                event.preventDefault();
                h.onClick(row);
              }}
            >
              {value}
            </a>
          );
        }
        const cls = "dt-cell-" + (h.type || "string");
        return (
          <td key={h.field + index} className={cls}>
            {value}
          </td>
        );
      });

    return <tr key={row._id}>{cells}</tr>;
  };
  return <tbody>{rows.map((row) => renderRowImpl(row))}</tbody>;
};

export default TableBody;
